# Sample PySys testcase
# Copyright (c) 2015-2016, 2018 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors. 
# Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG 

from pysys.constants import *
from apama.basetest import ApamaBaseTest
from apama.correlator import CorrelatorHelper
from apama.build import antBuild
from pysys.utils import filecopy

TEST_SUBJECT_DIR = PROJECT.TEST_SUBJECT_DIR + '/connectivity_plugin/java/JSON-Codec'

class PySysTest(ApamaBaseTest):

	def execute(self):
		
		# build the sample, putting the results into the testcase output dir
		antBuild(self, TEST_SUBJECT_DIR + '/build.xml', args=['-Doutput-dir=%s/Release'%self.output])

		# create a correlator
		correlator = CorrelatorHelper(self, name='correlator')
		
		# start the correlator and inject some EPL
		correlator.start(logfile=correlator.name+'.log', verbosity='INFO', 
			config=[self.input+'/test-config.yaml'], 
			# these properties are used within the test .yaml file to specify input/output locations
			arguments=[
				'-DTEST_OUTPUT_DIR=%s'%self.output, 
				'-DTEST_SUBJECT_DIR=%s'%TEST_SUBJECT_DIR,
			])
		correlator.injectEPL(['ConnectivityPluginsControl.mon', 'ConnectivityPlugins.mon'], filedir=PROJECT.APAMA_HOME+'/monitors')
		correlator.injectEPL('DemoApp.mon', filedir = TEST_SUBJECT_DIR+'/demo')

		# wait until the correlator receives the events (aborting if an error occurs)
		self.waitForSignal('correlator.log', expr="Sending special offer", condition="==2", 
			errorExpr=['( ERROR .*| WARN .*jsonChain.*)'], 
			process=correlator.process)
		
		# wait until 2 messages are received in this file
		self.waitForSignal('specialoffers-output.json.txt', expr="metadata=", condition="==2")
		
	def validate(self):
		# check the received events against the reference 
		self.assertDiff('specialoffers-output.json.txt', 'reference-specialoffers-output.json.txt', 
			filedir2=TEST_SUBJECT_DIR+'/demo')
